@@ -1,18 +1,20 @@
 /* Common routines & arrays. */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <ctype.h>
-#include <math.h>
-#include <kdebug.h>
-#include <sys/types.h>
-#include <stdarg.h>
 #include "clock.h"
 #include "../clock.h"
 #include "../pile.h"
 #include "../deck.h"
 
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
+#include <cctype>
+#include <cmath>
+#include <sys/types.h>
+#include <cstdarg>
+
+#include <kdebug.h>
+
 /* These two routines make and unmake moves. */
 
 #define PRINT 0
