@@ -11,11 +11,11 @@
  * event will the author be liable for any lost revenue or profits or
  * other special, indirect and consequential damages.
 */
-#ifndef _PILE_H
-#define _PILE_H
-
+#ifndef PILE_H
+#define PILE_H
 
 #include "card.h"
+
 #include <QPixmap>
 //Added by qt3to4:
 #include <QGraphicsPixmapItem>
@@ -65,7 +65,7 @@ public:
     bool legalRemove(const Card *c, bool demo = false) const;
 
     virtual void moveCards(CardList &c, Pile *to = 0);
-    void moveCardsBack(CardList &c, bool anim = true);
+    void moveCardsBack(CardList &c, int steps = -1 );
 
     void setRemoveFlags( int flag ) { removeFlags = flag; }
     void setAddFlags( int flag ) { addFlags = flag; }
@@ -145,6 +145,7 @@ public slots:
     virtual bool cardClicked(Card *c);
     virtual bool cardDblClicked(Card *c);
     virtual void relayoutCards();
+    virtual void waitForMoving(Card*);
 
 signals:
     void clicked(Card *c);
