@@ -13,11 +13,13 @@
 */
 
 #include "yukon.h"
+#include "deck.h"
+#include "patsolve/yukon.h"
+
+#include <cassert>
+
 #include <klocale.h>
 #include <kdebug.h>
-#include "deck.h"
-#include <assert.h>
-#include "patsolve/yukon.h"
 
 Yukon::Yukon( )
     : DealerScene( )
@@ -75,7 +77,7 @@ void Yukon::deal() {
 static class LocalDealerInfo10 : public DealerInfo
 {
 public:
-    LocalDealerInfo10() : DealerInfo(I18N_NOOP("&Yukon"), 10) {}
+    LocalDealerInfo10() : DealerInfo(I18N_NOOP("Yukon"), 10) {}
     virtual DealerScene *createGame() { return new Yukon(); }
 } gfi10;
 
